@@ -11,14 +11,12 @@
 #' # Select some text in Rstudio
 #' # Then call the function as an RStudio addin
 #' \dontrun{
-#' addin_spelling_grammar()
+#' gptstudio_spelling_grammar()
 #' }
-addin_spelling_grammar <- function() {
+gptstudio_spelling_grammar <- function() {
   cli_process_start("Sending query to ChatGPT")
-  gpt_chat_in_source(
-    task = "Improve spelling and grammar of the text",
-    style = getOption("gptstudio.code_style"),
-    skill = getOption("gptstudio.skill")
+  gptstudio_chat_in_source(
+    task = "Improve spelling and grammar of the text"
   )
   cli_process_done()
 }
