@@ -4,7 +4,12 @@
 ## gptstudio namespace: start
 #' @import cli
 #' @import rlang
+#' @import httr2
 #' @importFrom assertthat assert_that is.string is.number is.count
 #' @importFrom glue glue
 ## gptstudio namespace: end
-gptstudio_env <- new.env()
+NULL
+
+dummy <- function() {
+  SSEparser::SSEparser
+}
